@@ -12,19 +12,32 @@ using ModelingToolkit
             num_cons = 0;
             g = false, h = false, hv = false, fg = false, fgh = false,
             cons_j = false, cons_vjp = false, cons_jvp = false, cons_h = false,
-            lag_h = false)
+            lag_h = false
+        )
         p = isnothing(p) ? SciMLBase.NullParameters() : p
 
-        sys = complete(ModelingToolkit.modelingtoolkitize(OptimizationProblem(f, x, p;
-            lcons = fill(0.0,
-                num_cons),
-            ucons = fill(0.0,
-                num_cons))))
+        sys = complete(
+            ModelingToolkit.modelingtoolkitize(
+                OptimizationProblem(
+                    f, x, p;
+                    lcons = fill(
+                        0.0,
+                        num_cons
+                    ),
+                    ucons = fill(
+                        0.0,
+                        num_cons
+                    )
+                )
+            )
+        )
         #sys = ModelingToolkit.structural_simplify(sys)
         # don't need to pass `x` or `p` since they're defaults now
-        mtkprob = OptimizationProblem(sys, nothing; grad = g, hess = h,
+        mtkprob = OptimizationProblem(
+            sys, nothing; grad = g, hess = h,
             sparse = true, cons_j = cons_j, cons_h = cons_h,
-            cons_sparse = true)
+            cons_sparse = true
+        )
         f = mtkprob.f
 
         grad = (G, θ, args...) -> f.grad(G, θ, mtkprob.p, args...)
@@ -47,7 +60,8 @@ using ModelingToolkit
             cons_h = nothing
         end
 
-        return OptimizationFunction{true}(f.f, adtype; grad = grad, hess = hess, hv = hv,
+        return OptimizationFunction{true}(
+            f.f, adtype; grad = grad, hess = hess, hv = hv,
             cons = cons, cons_j = cons_j, cons_h = cons_h,
             hess_prototype = f.hess_prototype,
             cons_jac_prototype = f.cons_jac_prototype,
@@ -55,7 +69,8 @@ using ModelingToolkit
             expr = OptimizationBase.symbolify(f.expr),
             cons_expr = OptimizationBase.symbolify.(f.cons_expr),
             sys = sys,
-            observed = f.observed)
+            observed = f.observed
+        )
     end
 
     function OptimizationBase.instantiate_function(
@@ -63,20 +78,33 @@ using ModelingToolkit
             adtype::AutoSparse{<:AutoSymbolics}, num_cons = 0;
             g = false, h = false, hv = false, fg = false, fgh = false,
             cons_j = false, cons_vjp = false, cons_jvp = false, cons_h = false,
-            lag_h = false)
+            lag_h = false
+        )
         p = isnothing(cache.p) ? SciMLBase.NullParameters() : cache.p
 
-        sys = complete(ModelingToolkit.modelingtoolkitize(OptimizationProblem(f, cache.u0,
-            cache.p;
-            lcons = fill(0.0,
-                num_cons),
-            ucons = fill(0.0,
-                num_cons))))
+        sys = complete(
+            ModelingToolkit.modelingtoolkitize(
+                OptimizationProblem(
+                    f, cache.u0,
+                    cache.p;
+                    lcons = fill(
+                        0.0,
+                        num_cons
+                    ),
+                    ucons = fill(
+                        0.0,
+                        num_cons
+                    )
+                )
+            )
+        )
         #sys = ModelingToolkit.structural_simplify(sys)
         # don't need to pass `x` or `p` since they're defaults now
-        mtkprob = OptimizationProblem(sys, nothing; grad = g, hess = h,
+        mtkprob = OptimizationProblem(
+            sys, nothing; grad = g, hess = h,
             sparse = true, cons_j = cons_j, cons_h = cons_h,
-            cons_sparse = true)
+            cons_sparse = true
+        )
         f = mtkprob.f
 
         grad = (G, θ, args...) -> f.grad(G, θ, mtkprob.p, args...)
@@ -98,7 +126,8 @@ using ModelingToolkit
             cons_h = nothing
         end
 
-        return OptimizationFunction{true}(f.f, adtype; grad = grad, hess = hess, hv = hv,
+        return OptimizationFunction{true}(
+            f.f, adtype; grad = grad, hess = hess, hv = hv,
             cons = cons, cons_j = cons_j, cons_h = cons_h,
             hess_prototype = f.hess_prototype,
             cons_jac_prototype = f.cons_jac_prototype,
@@ -106,26 +135,40 @@ using ModelingToolkit
             expr = OptimizationBase.symbolify(f.expr),
             cons_expr = OptimizationBase.symbolify.(f.cons_expr),
             sys = sys,
-            observed = f.observed)
+            observed = f.observed
+        )
     end
 
     function OptimizationBase.instantiate_function(
             f::OptimizationFunction{true}, x, adtype::AutoSymbolics, p,
             num_cons = 0; g = false, h = false, hv = false, fg = false, fgh = false,
             cons_j = false, cons_vjp = false, cons_jvp = false, cons_h = false,
-            lag_h = false)
+            lag_h = false
+        )
         p = isnothing(p) ? SciMLBase.NullParameters() : p
 
-        sys = complete(ModelingToolkit.modelingtoolkitize(OptimizationProblem(f, x, p;
-            lcons = fill(0.0,
-                num_cons),
-            ucons = fill(0.0,
-                num_cons))))
+        sys = complete(
+            ModelingToolkit.modelingtoolkitize(
+                OptimizationProblem(
+                    f, x, p;
+                    lcons = fill(
+                        0.0,
+                        num_cons
+                    ),
+                    ucons = fill(
+                        0.0,
+                        num_cons
+                    )
+                )
+            )
+        )
         #sys = ModelingToolkit.structural_simplify(sys)
         # don't need to pass `x` or `p` since they're defaults now
-        mtkprob = OptimizationProblem(sys, nothing; grad = g, hess = h,
+        mtkprob = OptimizationProblem(
+            sys, nothing; grad = g, hess = h,
             sparse = false, cons_j = cons_j, cons_h = cons_h,
-            cons_sparse = false)
+            cons_sparse = false
+        )
         f = mtkprob.f
 
         grad = (G, θ, args...) -> f.grad(G, θ, mtkprob.p, args...)
@@ -148,7 +191,8 @@ using ModelingToolkit
             cons_h = nothing
         end
 
-        return OptimizationFunction{true}(f.f, adtype; grad = grad, hess = hess, hv = hv,
+        return OptimizationFunction{true}(
+            f.f, adtype; grad = grad, hess = hess, hv = hv,
             cons = cons, cons_j = cons_j, cons_h = cons_h,
             hess_prototype = f.hess_prototype,
             cons_jac_prototype = f.cons_jac_prototype,
@@ -156,7 +200,8 @@ using ModelingToolkit
             expr = OptimizationBase.symbolify(f.expr),
             cons_expr = OptimizationBase.symbolify.(f.cons_expr),
             sys = sys,
-            observed = f.observed)
+            observed = f.observed
+        )
     end
 
     function OptimizationBase.instantiate_function(
@@ -164,20 +209,33 @@ using ModelingToolkit
             adtype::AutoSymbolics, num_cons = 0;
             g = false, h = false, hv = false, fg = false, fgh = false,
             cons_j = false, cons_vjp = false, cons_jvp = false, cons_h = false,
-            lag_h = false)
+            lag_h = false
+        )
         p = isnothing(cache.p) ? SciMLBase.NullParameters() : cache.p
 
-        sys = complete(ModelingToolkit.modelingtoolkitize(OptimizationProblem(f, cache.u0,
-            cache.p;
-            lcons = fill(0.0,
-                num_cons),
-            ucons = fill(0.0,
-                num_cons))))
+        sys = complete(
+            ModelingToolkit.modelingtoolkitize(
+                OptimizationProblem(
+                    f, cache.u0,
+                    cache.p;
+                    lcons = fill(
+                        0.0,
+                        num_cons
+                    ),
+                    ucons = fill(
+                        0.0,
+                        num_cons
+                    )
+                )
+            )
+        )
         #sys = ModelingToolkit.structural_simplify(sys)
         # don't need to pass `x` or `p` since they're defaults now
-        mtkprob = OptimizationProblem(sys, nothing; grad = g, hess = h,
+        mtkprob = OptimizationProblem(
+            sys, nothing; grad = g, hess = h,
             sparse = false, cons_j = cons_j, cons_h = cons_h,
-            cons_sparse = false)
+            cons_sparse = false
+        )
         f = mtkprob.f
 
         grad = (G, θ, args...) -> f.grad(G, θ, mtkprob.p, args...)
@@ -200,7 +258,8 @@ using ModelingToolkit
             cons_h = nothing
         end
 
-        return OptimizationFunction{true}(f.f, adtype; grad = grad, hess = hess, hv = hv,
+        return OptimizationFunction{true}(
+            f.f, adtype; grad = grad, hess = hess, hv = hv,
             cons = cons, cons_j = cons_j, cons_h = cons_h,
             hess_prototype = f.hess_prototype,
             cons_jac_prototype = f.cons_jac_prototype,
@@ -208,7 +267,8 @@ using ModelingToolkit
             expr = OptimizationBase.symbolify(f.expr),
             cons_expr = OptimizationBase.symbolify.(f.cons_expr),
             sys = sys,
-            observed = f.observed)
+            observed = f.observed
+        )
     end
 end
 
