@@ -4,11 +4,11 @@ import SciMLBase: OptimizationFunction
 import OptimizationBase.LinearAlgebra: I
 import DifferentiationInterface
 import DifferentiationInterface: prepare_gradient, prepare_hessian, prepare_hvp,
-                                 prepare_jacobian, value_and_gradient!,
-                                 value_derivative_and_second_derivative!,
-                                 value_and_gradient, value_derivative_and_second_derivative,
-                                 gradient!, hessian!, hvp!, jacobian!, gradient, hessian,
-                                 hvp, jacobian
+    prepare_jacobian, value_and_gradient!,
+    value_derivative_and_second_derivative!,
+    value_and_gradient, value_derivative_and_second_derivative,
+    gradient!, hessian!, hvp!, jacobian!, gradient, hessian,
+    hvp, jacobian
 using ADTypes
 using SparseConnectivityTracer, SparseMatrixColorings
 
@@ -17,17 +17,18 @@ function instantiate_function(
         p = SciMLBase.NullParameters(), num_cons = 0;
         g = false, h = false, hv = false, fg = false, fgh = false,
         cons_j = false, cons_vjp = false, cons_jvp = false, cons_h = false,
-        lag_h = false)
+        lag_h = false
+    )
     adtype, soadtype = generate_sparse_adtype(adtype)
 
     if g == true && f.grad === nothing
         prep_grad = prepare_gradient(f.f, adtype.dense_ad, x, Constant(p))
         function grad(res, θ)
-            gradient!(f.f, res, prep_grad, adtype.dense_ad, θ, Constant(p))
+            return gradient!(f.f, res, prep_grad, adtype.dense_ad, θ, Constant(p))
         end
         if p !== SciMLBase.NullParameters()
             function grad(res, θ, p)
-                gradient!(f.f, res, prep_grad, adtype.dense_ad, θ, Constant(p))
+                return gradient!(f.f, res, prep_grad, adtype.dense_ad, θ, Constant(p))
             end
         end
     elseif g == true
@@ -41,16 +42,22 @@ function instantiate_function(
             prep_grad = prepare_gradient(f.f, adtype.dense_ad, x, Constant(p))
         end
         function fg!(res, θ)
-            (y,
-                _) = value_and_gradient!(
-                f.f, res, prep_grad, adtype.dense_ad, θ, Constant(p))
+            (
+                y,
+                _,
+            ) = value_and_gradient!(
+                f.f, res, prep_grad, adtype.dense_ad, θ, Constant(p)
+            )
             return y
         end
         if p !== SciMLBase.NullParameters()
             function fg!(res, θ, p)
-                (y,
-                    _) = value_and_gradient!(
-                    f.f, res, prep_grad, adtype.dense_ad, θ, Constant(p))
+                (
+                    y,
+                    _,
+                ) = value_and_gradient!(
+                    f.f, res, prep_grad, adtype.dense_ad, θ, Constant(p)
+                )
                 return y
             end
         end
@@ -65,14 +72,14 @@ function instantiate_function(
     if f.hess === nothing && h == true
         prep_hess = prepare_hessian(f.f, soadtype, x, Constant(p))
         function hess(res, θ)
-            hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
+            return hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
         end
         hess_sparsity = prep_hess.coloring_result.A
         hess_colors = prep_hess.coloring_result.color
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function hess(res, θ, p)
-                hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
+                return hessian!(f.f, res, prep_hess, soadtype, θ, Constant(p))
             end
         end
     elseif h == true
@@ -83,18 +90,24 @@ function instantiate_function(
 
     if fgh == true && f.fgh === nothing
         function fgh!(G, H, θ)
-            (y,
+            (
+                y,
                 _,
-                _) = value_derivative_and_second_derivative!(
-                f.f, G, H, prep_hess, soadtype.dense_ad, θ, Constant(p))
+                _,
+            ) = value_derivative_and_second_derivative!(
+                f.f, G, H, prep_hess, soadtype.dense_ad, θ, Constant(p)
+            )
             return y
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function fgh!(G, H, θ, p)
-                (y,
+                (
+                    y,
                     _,
-                    _) = value_derivative_and_second_derivative!(
-                    f.f, G, H, prep_hess, soadtype.dense_ad, θ, Constant(p))
+                    _,
+                ) = value_derivative_and_second_derivative!(
+                    f.f, G, H, prep_hess, soadtype.dense_ad, θ, Constant(p)
+                )
                 return y
             end
         end
@@ -106,13 +119,14 @@ function instantiate_function(
 
     if hv == true && f.hv === nothing
         prep_hvp = prepare_hvp(
-            f.f, soadtype.dense_ad, x, (zeros(eltype(x), size(x)),), Constant(p))
+            f.f, soadtype.dense_ad, x, (zeros(eltype(x), size(x)),), Constant(p)
+        )
         function hv!(H, θ, v)
-            only(hvp!(f.f, (H,), prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p)))
+            return only(hvp!(f.f, (H,), prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p)))
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function hv!(H, θ, v, p)
-                only(hvp!(f.f, (H,), prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p)))
+                return only(hvp!(f.f, (H,), prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p)))
             end
         end
     elseif hv == true
@@ -153,7 +167,7 @@ function instantiate_function(
         prep_jac = prepare_jacobian(cons_oop, adtype, x)
         function cons_j!(J, θ)
             jacobian!(cons_oop, J, prep_jac, adtype, θ)
-            if size(J, 1) == 1
+            return if size(J, 1) == 1
                 J = vec(J)
             end
         end
@@ -167,9 +181,10 @@ function instantiate_function(
 
     if f.cons_vjp === nothing && cons_vjp == true && f.cons !== nothing
         prep_pullback = prepare_pullback(
-            cons_oop, adtype.dense_ad, x, (ones(eltype(x), num_cons),))
+            cons_oop, adtype.dense_ad, x, (ones(eltype(x), num_cons),)
+        )
         function cons_vjp!(J, θ, v)
-            only(pullback!(cons_oop, (J,), prep_pullback, adtype.dense_ad, θ, (v,)))
+            return only(pullback!(cons_oop, (J,), prep_pullback, adtype.dense_ad, θ, (v,)))
         end
     elseif cons_vjp === true && f.cons !== nothing
         cons_vjp! = (J, θ, v) -> f.cons_vjp(J, θ, v, p)
@@ -179,9 +194,10 @@ function instantiate_function(
 
     if f.cons_jvp === nothing && cons_jvp == true && f.cons !== nothing
         prep_pushforward = prepare_pushforward(
-            cons_oop, adtype.dense_ad, x, (ones(eltype(x), length(x)),))
+            cons_oop, adtype.dense_ad, x, (ones(eltype(x), length(x)),)
+        )
         function cons_jvp!(J, θ, v)
-            only(pushforward!(cons_oop, (J,), prep_pushforward, adtype.dense_ad, θ, (v,)))
+            return only(pushforward!(cons_oop, (J,), prep_pushforward, adtype.dense_ad, θ, (v,)))
         end
     elseif cons_jvp === true && f.cons !== nothing
         cons_jvp! = (J, θ, v) -> f.cons_jvp(J, θ, v, p)
@@ -192,8 +208,10 @@ function instantiate_function(
     conshess_sparsity = f.cons_hess_prototype
     conshess_colors = f.cons_hess_colorvec
     if f.cons !== nothing && f.cons_h === nothing && cons_h == true
-        prep_cons_hess = [prepare_hessian(cons_oop, soadtype, x, Constant(i))
-                          for i in 1:num_cons]
+        prep_cons_hess = [
+            prepare_hessian(cons_oop, soadtype, x, Constant(i))
+                for i in 1:num_cons
+        ]
         colores = getfield.(prep_cons_hess, :coloring_result)
         conshess_sparsity = getfield.(colores, :A)
         conshess_colors = getfield.(colores, :color)
@@ -201,6 +219,7 @@ function instantiate_function(
             for i in 1:num_cons
                 hessian!(cons_oop, H[i], prep_cons_hess[i], soadtype, θ, Constant(i))
             end
+            return
         end
     elseif cons_h == true && f.cons !== nothing
         cons_h! = (res, θ) -> f.cons_h(res, θ, p)
@@ -213,23 +232,27 @@ function instantiate_function(
     if f.cons !== nothing && lag_h == true && f.lag_h === nothing
         lag_prep = prepare_hessian(
             lagrangian, soadtype, x, Constant(one(eltype(x))),
-            Constant(ones(eltype(x), num_cons)), Constant(p))
+            Constant(ones(eltype(x), num_cons)), Constant(p)
+        )
         lag_hess_prototype = lag_prep.coloring_result.A
         lag_hess_colors = lag_prep.coloring_result.color
 
         function lag_h!(H::AbstractMatrix, θ, σ, λ)
-            if σ == zero(eltype(θ))
+            return if σ == zero(eltype(θ))
                 cons_h!(H, θ)
                 H *= λ
             else
-                hessian!(lagrangian, H, lag_prep, soadtype, θ,
-                    Constant(σ), Constant(λ), Constant(p))
+                hessian!(
+                    lagrangian, H, lag_prep, soadtype, θ,
+                    Constant(σ), Constant(λ), Constant(p)
+                )
             end
         end
 
         function lag_h!(h, θ, σ, λ)
             H = hessian(
-                lagrangian, lag_prep, soadtype, θ, Constant(σ), Constant(λ), Constant(p))
+                lagrangian, lag_prep, soadtype, θ, Constant(σ), Constant(λ), Constant(p)
+            )
             k = 0
             rows, cols, _ = findnz(H)
             for (i, j) in zip(rows, cols)
@@ -238,22 +261,27 @@ function instantiate_function(
                     h[k] = H[i, j]
                 end
             end
+            return
         end
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function lag_h!(H::AbstractMatrix, θ, σ, λ, p)
-                if σ == zero(eltype(θ))
+                return if σ == zero(eltype(θ))
                     cons_h(H, θ)
                     H *= λ
                 else
-                    hessian!(lagrangian, H, lag_prep, soadtype, θ,
-                        Constant(σ), Constant(λ), Constant(p))
+                    hessian!(
+                        lagrangian, H, lag_prep, soadtype, θ,
+                        Constant(σ), Constant(λ), Constant(p)
+                    )
                 end
             end
 
             function lag_h!(h, θ, σ, λ, p)
-                H = hessian(lagrangian, lag_prep, soadtype, θ,
-                    Constant(σ), Constant(λ), Constant(p))
+                H = hessian(
+                    lagrangian, lag_prep, soadtype, θ,
+                    Constant(σ), Constant(λ), Constant(p)
+                )
                 k = 0
                 rows, cols, _ = findnz(H)
                 for (i, j) in zip(rows, cols)
@@ -262,6 +290,7 @@ function instantiate_function(
                         h[k] = H[i, j]
                     end
                 end
+                return
             end
         end
     elseif lag_h == true
@@ -269,7 +298,8 @@ function instantiate_function(
     else
         lag_h! = nothing
     end
-    return OptimizationFunction{true}(f.f, adtype;
+    return OptimizationFunction{true}(
+        f.f, adtype;
         grad = grad, fg = fg!, hess = hess, hv = hv!, fgh = fgh!,
         cons = cons, cons_j = cons_j!, cons_h = cons_h!,
         cons_vjp = cons_vjp!, cons_jvp = cons_jvp!,
@@ -284,12 +314,14 @@ function instantiate_function(
         lag_hess_colorvec = lag_hess_colors,
         sys = f.sys,
         expr = f.expr,
-        cons_expr = f.cons_expr)
+        cons_expr = f.cons_expr
+    )
 end
 
 function instantiate_function(
         f::OptimizationFunction{true}, cache::OptimizationBase.ReInitCache,
-        adtype::ADTypes.AutoSparse{<:AbstractADType}, num_cons = 0; kwargs...)
+        adtype::ADTypes.AutoSparse{<:AbstractADType}, num_cons = 0; kwargs...
+    )
     x = cache.u0
     p = cache.p
 
@@ -301,17 +333,18 @@ function instantiate_function(
         p = SciMLBase.NullParameters(), num_cons = 0;
         g = false, h = false, hv = false, fg = false, fgh = false,
         cons_j = false, cons_vjp = false, cons_jvp = false, cons_h = false,
-        lag_h = false)
+        lag_h = false
+    )
     adtype, soadtype = generate_sparse_adtype(adtype)
 
     if g == true && f.grad === nothing
         prep_grad = prepare_gradient(f.f, adtype.dense_ad, x, Constant(p))
         function grad(θ)
-            gradient(f.f, prep_grad, adtype.dense_ad, θ, Constant(p))
+            return gradient(f.f, prep_grad, adtype.dense_ad, θ, Constant(p))
         end
         if p !== SciMLBase.NullParameters() && p !== nothing
             function grad(θ, p)
-                gradient(f.f, prep_grad, adtype.dense_ad, θ, Constant(p))
+                return gradient(f.f, prep_grad, adtype.dense_ad, θ, Constant(p))
             end
         end
     elseif g == true
@@ -342,19 +375,25 @@ function instantiate_function(
 
     if fgh == true && f.fgh === nothing
         function fgh!(θ)
-            (y,
+            (
+                y,
                 G,
-                H) = value_derivative_and_second_derivative(
-                f.f, prep_hess, soadtype, θ, Constant(p))
+                H,
+            ) = value_derivative_and_second_derivative(
+                f.f, prep_hess, soadtype, θ, Constant(p)
+            )
             return y, G, H
         end
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function fgh!(θ, p)
-                (y,
+                (
+                    y,
                     G,
-                    H) = value_derivative_and_second_derivative(
-                    f.f, prep_hess, soadtype, θ, Constant(p))
+                    H,
+                ) = value_derivative_and_second_derivative(
+                    f.f, prep_hess, soadtype, θ, Constant(p)
+                )
                 return y, G, H
             end
         end
@@ -369,14 +408,14 @@ function instantiate_function(
     if h == true && f.hess === nothing
         prep_hess = prepare_hessian(f.f, soadtype, x, Constant(p))
         function hess(θ)
-            hessian(f.f, prep_hess, soadtype, θ, Constant(p))
+            return hessian(f.f, prep_hess, soadtype, θ, Constant(p))
         end
         hess_sparsity = prep_hess.coloring_result.A
         hess_colors = prep_hess.coloring_result.color
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function hess(θ, p)
-                hessian(f.f, prep_hess, soadtype, θ, Constant(p))
+                return hessian(f.f, prep_hess, soadtype, θ, Constant(p))
             end
         end
     elseif h == true
@@ -387,14 +426,15 @@ function instantiate_function(
 
     if hv == true && f.hv === nothing
         prep_hvp = prepare_hvp(
-            f.f, soadtype.dense_ad, x, (zeros(eltype(x), size(x)),), Constant(p))
+            f.f, soadtype.dense_ad, x, (zeros(eltype(x), size(x)),), Constant(p)
+        )
         function hv!(θ, v)
-            only(hvp(f.f, prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p)))
+            return only(hvp(f.f, prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p)))
         end
 
         if p !== SciMLBase.NullParameters() && p !== nothing
             function hv!(θ, v, p)
-                only(hvp(f.f, prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p)))
+                return only(hvp(f.f, prep_hvp, soadtype.dense_ad, θ, (v,), Constant(p)))
             end
         end
     elseif hv == true
@@ -434,9 +474,10 @@ function instantiate_function(
 
     if f.cons_vjp === nothing && cons_vjp == true && f.cons !== nothing
         prep_pullback = prepare_pullback(
-            f.cons, adtype.dense_ad, x, (ones(eltype(x), num_cons),), Constant(p))
+            f.cons, adtype.dense_ad, x, (ones(eltype(x), num_cons),), Constant(p)
+        )
         function cons_vjp!(θ, v)
-            only(pullback(f.cons, prep_pullback, adtype.dense_ad, θ, (v,), Constant(p)))
+            return only(pullback(f.cons, prep_pullback, adtype.dense_ad, θ, (v,), Constant(p)))
         end
     elseif cons_vjp === true && f.cons !== nothing
         cons_vjp! = (θ, v) -> f.cons_vjp(θ, v, p)
@@ -446,10 +487,14 @@ function instantiate_function(
 
     if f.cons_jvp === nothing && cons_jvp == true && f.cons !== nothing
         prep_pushforward = prepare_pushforward(
-            f.cons, adtype.dense_ad, x, (ones(eltype(x), length(x)),), Constant(p))
+            f.cons, adtype.dense_ad, x, (ones(eltype(x), length(x)),), Constant(p)
+        )
         function cons_jvp!(θ, v)
-            only(pushforward(
-                f.cons, prep_pushforward, adtype.dense_ad, θ, (v,), Constant(p)))
+            return only(
+                pushforward(
+                    f.cons, prep_pushforward, adtype.dense_ad, θ, (v,), Constant(p)
+                )
+            )
         end
     elseif cons_jvp === true && f.cons !== nothing
         cons_jvp! = (θ, v) -> f.cons_jvp(θ, v, p)
@@ -461,10 +506,12 @@ function instantiate_function(
     conshess_colors = f.cons_hess_colorvec
     if f.cons !== nothing && cons_h == true && f.cons_h === nothing
         function cons_i(x, i)
-            f.cons(x, p)[i]
+            return f.cons(x, p)[i]
         end
-        prep_cons_hess = [prepare_hessian(cons_i, soadtype, x, Constant(i))
-                          for i in 1:num_cons]
+        prep_cons_hess = [
+            prepare_hessian(cons_i, soadtype, x, Constant(i))
+                for i in 1:num_cons
+        ]
 
         function cons_h!(θ)
             H = map(1:num_cons) do i
@@ -486,13 +533,16 @@ function instantiate_function(
     if f.cons !== nothing && lag_h == true && f.lag_h === nothing
         lag_prep = prepare_hessian(
             lagrangian, soadtype, x, Constant(one(eltype(x))),
-            Constant(ones(eltype(x), num_cons)), Constant(p))
+            Constant(ones(eltype(x), num_cons)), Constant(p)
+        )
         function lag_h!(θ, σ, λ)
             if σ == zero(eltype(θ))
                 return λ .* cons_h!(θ)
             else
-                hess = hessian(lagrangian, lag_prep, soadtype, θ,
-                    Constant(σ), Constant(λ), Constant(p))
+                hess = hessian(
+                    lagrangian, lag_prep, soadtype, θ,
+                    Constant(σ), Constant(λ), Constant(p)
+                )
                 return hess
             end
         end
@@ -505,7 +555,8 @@ function instantiate_function(
                     return λ .* cons_h!(θ)
                 else
                     hess = hessian(
-                        lagrangian, lag_prep, θ, Constant(σ), Constant(λ), Constant(p))
+                        lagrangian, lag_prep, θ, Constant(σ), Constant(λ), Constant(p)
+                    )
                     return hess
                 end
             end
@@ -515,7 +566,8 @@ function instantiate_function(
     else
         lag_h! = nothing
     end
-    return OptimizationFunction{false}(f.f, adtype;
+    return OptimizationFunction{false}(
+        f.f, adtype;
         grad = grad, fg = fg!, hess = hess, hv = hv!, fgh = fgh!,
         cons = cons, cons_j = cons_j!, cons_h = cons_h!,
         cons_vjp = cons_vjp!, cons_jvp = cons_jvp!,
@@ -530,12 +582,14 @@ function instantiate_function(
         lag_hess_colorvec = lag_hess_colors,
         sys = f.sys,
         expr = f.expr,
-        cons_expr = f.cons_expr)
+        cons_expr = f.cons_expr
+    )
 end
 
 function instantiate_function(
         f::OptimizationFunction{false}, cache::OptimizationBase.ReInitCache,
-        adtype::ADTypes.AutoSparse{<:AbstractADType}, num_cons = 0; kwargs...)
+        adtype::ADTypes.AutoSparse{<:AbstractADType}, num_cons = 0; kwargs...
+    )
     x = cache.u0
     p = cache.p
 
